@@ -3,7 +3,7 @@
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -42,8 +42,6 @@ else:
     except ImportError:
         import warnings
 
-        warnings.warn(
-            "nltk.app.wordfreq not loaded (requires the matplotlib library)."
-        )
+        warnings.warn("nltk.app.wordfreq not loaded (requires the matplotlib library).")
     else:
         from nltk.app.wordfreq_app import app as wordfreq
