@@ -2,13 +2,13 @@
 #
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """Corpus reader for the XML version of the British National Corpus."""
 
 from nltk.corpus.reader.util import concat
-from nltk.corpus.reader.xmldocs import XMLCorpusReader, XMLCorpusView, ElementTree
+from nltk.corpus.reader.xmldocs import ElementTree, XMLCorpusReader, XMLCorpusView
 
 
 class BNCCorpusReader(XMLCorpusReader):
@@ -19,7 +19,7 @@ class BNCCorpusReader(XMLCorpusReader):
     ``words()``, ``sents()``, ``tagged_words()``, and ``tagged_sents()``.
 
     You can obtain the full version of the BNC corpus at
-    http://www.ota.ox.ac.uk/desc/2554
+    https://www.ota.ox.ac.uk/desc/2554
 
     If you extracted the archive to a directory called `BNC`, then you can
     instantiate the reader as::
@@ -165,9 +165,16 @@ class BNCWordView(XMLCorpusView):
     A stream backed corpus view specialized for use with the BNC corpus.
     """
 
-    tags_to_ignore = set(
-        ["pb", "gap", "vocal", "event", "unclear", "shift", "pause", "align"]
-    )
+    tags_to_ignore = {
+        "pb",
+        "gap",
+        "vocal",
+        "event",
+        "unclear",
+        "shift",
+        "pause",
+        "align",
+    }
     """These tags are ignored. For their description refer to the
     technical documentation, for example,
     http://www.natcorp.ox.ac.uk/docs/URG/ref-vocal.html
