@@ -2,7 +2,7 @@
 #
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -94,10 +94,10 @@ class VerbnetCorpusReader(XMLCorpusReader):
             if isinstance(vnclass, str):
                 vnclass = self.vnclass(vnclass)
             return sum(
-                [
+                (
                     member.get("wn", "").split()
                     for member in vnclass.findall("MEMBERS/MEMBER")
-                ],
+                ),
                 [],
             )
 
@@ -160,7 +160,7 @@ class VerbnetCorpusReader(XMLCorpusReader):
                     assert False  # we saw it during _index()!
 
         else:
-            raise ValueError("Unknown identifier {}".format(fileid_or_classid))
+            raise ValueError(f"Unknown identifier {fileid_or_classid}")
 
     def fileids(self, vnclass_ids=None):
         """
@@ -294,18 +294,19 @@ class VerbnetCorpusReader(XMLCorpusReader):
             vnclass = fileid[:-4]  # strip the '.xml'
             self._class_to_fileid[vnclass] = fileid
             self._shortid_to_longid[self.shortid(vnclass)] = vnclass
-            for m in self._INDEX_RE.finditer(self.open(fileid).read()):
-                groups = m.groups()
-                if groups[0] is not None:
-                    self._lemma_to_class[groups[0]].append(vnclass)
-                    for wn in groups[1].split():
-                        self._wordnet_to_class[wn].append(vnclass)
-                elif groups[2] is not None:
-                    self._class_to_fileid[groups[2]] = fileid
-                    vnclass = groups[2]  # for <MEMBER> elts.
-                    self._shortid_to_longid[self.shortid(vnclass)] = vnclass
-                else:
-                    assert False, "unexpected match condition"
+            with self.open(fileid) as fp:
+                for m in self._INDEX_RE.finditer(fp.read()):
+                    groups = m.groups()
+                    if groups[0] is not None:
+                        self._lemma_to_class[groups[0]].append(vnclass)
+                        for wn in groups[1].split():
+                            self._wordnet_to_class[wn].append(vnclass)
+                    elif groups[2] is not None:
+                        self._class_to_fileid[groups[2]] = fileid
+                        vnclass = groups[2]  # for <MEMBER> elts.
+                        self._shortid_to_longid[self.shortid(vnclass)] = vnclass
+                    else:
+                        assert False, "unexpected match condition"
 
     ######################################################################
     # { Identifier conversion
@@ -440,7 +441,7 @@ class VerbnetCorpusReader(XMLCorpusReader):
         the given VerbNet class.
 
         :param vnclass: A VerbNet class identifier; or an ElementTree
-        containing the xml contents of a VerbNet class.
+            containing the xml contents of a VerbNet class.
         """
         if isinstance(vnclass, str):
             vnclass = self.vnclass(vnclass)
@@ -621,4 +622,4 @@ class VerbnetCorpusReader(XMLCorpusReader):
             pieces.append(
                 "{}({})".format(predicate["predicate_value"], ", ".join(arguments))
             )
-        return "\n".join("{}* {}".format(indent, piece) for piece in pieces)
+        return "\n".join(f"{indent}* {piece}" for piece in pieces)
