@@ -1,9 +1,9 @@
 # Natural Language Toolkit: graphical representations package
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 # Import Tkinter-based modules if Tkinter is installed
@@ -12,7 +12,7 @@ try:
 except ImportError:
     import warnings
 
-    warnings.warn("nltk.draw package not loaded " "(please install Tkinter library).")
+    warnings.warn("nltk.draw package not loaded (please install Tkinter library).")
 else:
     from nltk.draw.cfg import ProductionList, CFGEditor, CFGDemo
     from nltk.draw.tree import (
@@ -25,9 +25,3 @@ else:
     from nltk.draw.table import Table
 
 from nltk.draw.dispersion import dispersion_plot
-
-# skip doctests from this package
-def setup_module(module):
-    from nose import SkipTest
-
-    raise SkipTest("nltk.draw examples are not doctests")
