@@ -2,12 +2,13 @@
 #
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Ilia Kurenkov <ilia.kurenkov@gmail.com>
-# URL: <http://nltk.org/>
+#         Manu Joseph <manujosephv@gmail.com>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 """Language Models"""
 
 from nltk.lm.api import LanguageModel, Smoothing
-from nltk.lm.smoothing import KneserNey, WittenBell
+from nltk.lm.smoothing import AbsoluteDiscounting, KneserNey, WittenBell
 
 
 class MLE(LanguageModel):
@@ -59,6 +60,32 @@ class Laplace(Lidstone):
         super().__init__(1, *args, **kwargs)
 
 
+class StupidBackoff(LanguageModel):
+    """Provides StupidBackoff scores.
+
+    In addition to initialization arguments from BaseNgramModel also requires
+    a parameter alpha with which we scale the lower order probabilities.
+    Note that this is not a true probability distribution as scores for ngrams
+    of the same order do not sum up to unity.
+    """
+
+    def __init__(self, alpha=0.4, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.alpha = alpha
+
+    def unmasked_score(self, word, context=None):
+        if not context:
+            # Base recursion
+            return self.counts.unigrams.freq(word)
+        counts = self.context_counts(context)
+        word_count = counts[word]
+        norm_count = counts.N()
+        if word_count > 0:
+            return word_count / norm_count
+        else:
+            return self.alpha * self.unmasked_score(word, context[1:])
+
+
 class InterpolatedLanguageModel(LanguageModel):
     """Logic common to all interpolated language models.
 
@@ -67,7 +94,6 @@ class InterpolatedLanguageModel(LanguageModel):
     """
 
     def __init__(self, smoothing_cls, order, **kwargs):
-        assert issubclass(smoothing_cls, Smoothing)
         params = kwargs.pop("params", {})
         super().__init__(order, **kwargs)
         self.estimator = smoothing_cls(self.vocab, self.counts, **params)
@@ -80,8 +106,9 @@ class InterpolatedLanguageModel(LanguageModel):
             # It can also happen that we have no data for this context.
             # In that case we defer to the lower-order ngram.
             # This is the same as setting alpha to 0 and gamma to 1.
-            return self.unmasked_score(word, context[1:])
-        alpha, gamma = self.estimator.alpha_gamma(word, context)
+            alpha, gamma = 0, 1
+        else:
+            alpha, gamma = self.estimator.alpha_gamma(word, context)
         return alpha + gamma * self.unmasked_score(word, context[1:])
 
 
@@ -92,8 +119,23 @@ class WittenBellInterpolated(InterpolatedLanguageModel):
         super().__init__(WittenBell, order, **kwargs)
 
 
+class AbsoluteDiscountingInterpolated(InterpolatedLanguageModel):
+    """Interpolated version of smoothing with absolute discount."""
+
+    def __init__(self, order, discount=0.75, **kwargs):
+        super().__init__(
+            AbsoluteDiscounting, order, params={"discount": discount}, **kwargs
+        )
+
+
 class KneserNeyInterpolated(InterpolatedLanguageModel):
     """Interpolated version of Kneser-Ney smoothing."""
 
     def __init__(self, order, discount=0.1, **kwargs):
-        super().__init__(KneserNey, order, params={"discount": discount}, **kwargs)
+        if not (0 <= discount <= 1):
+            raise ValueError(
+                "Discount must be between 0 and 1 for probabilities to sum to unity."
+            )
+        super().__init__(
+            KneserNey, order, params={"discount": discount, "order": order}, **kwargs
+        )
