@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: An Incremental Earley Chart Parser
 #
 # Copyright (C) 2001-2021 NLTK Project
@@ -7,7 +6,7 @@
 #         Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 #         Jean Mark Gawron <gawron@mail.sdsu.edu>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -29,29 +28,29 @@ algorithm, originally formulated by Jay Earley (1970).
 from time import perf_counter
 
 from nltk.parse.chart import (
+    BottomUpPredictCombineRule,
+    BottomUpPredictRule,
+    CachedTopDownPredictRule,
     Chart,
     ChartParser,
     EdgeI,
+    EmptyPredictRule,
+    FilteredBottomUpPredictCombineRule,
+    FilteredSingleEdgeFundamentalRule,
     LeafEdge,
     LeafInitRule,
-    BottomUpPredictRule,
-    BottomUpPredictCombineRule,
-    TopDownInitRule,
     SingleEdgeFundamentalRule,
-    EmptyPredictRule,
-    CachedTopDownPredictRule,
-    FilteredSingleEdgeFundamentalRule,
-    FilteredBottomUpPredictCombineRule,
+    TopDownInitRule,
 )
 from nltk.parse.featurechart import (
+    FeatureBottomUpPredictCombineRule,
+    FeatureBottomUpPredictRule,
     FeatureChart,
     FeatureChartParser,
+    FeatureEmptyPredictRule,
+    FeatureSingleEdgeFundamentalRule,
     FeatureTopDownInitRule,
     FeatureTopDownPredictRule,
-    FeatureEmptyPredictRule,
-    FeatureBottomUpPredictRule,
-    FeatureBottomUpPredictCombineRule,
-    FeatureSingleEdgeFundamentalRule,
 )
 
 # ////////////////////////////////////////////////////////////
@@ -196,8 +195,7 @@ class CompleterRule(CompleteFundamentalRule):
 
     def apply(self, chart, grammar, edge):
         if not isinstance(edge, LeafEdge):
-            for new_edge in self._fundamental_rule.apply(chart, grammar, edge):
-                yield new_edge
+            yield from self._fundamental_rule.apply(chart, grammar, edge)
 
 
 class ScannerRule(CompleteFundamentalRule):
@@ -205,8 +203,7 @@ class ScannerRule(CompleteFundamentalRule):
 
     def apply(self, chart, grammar, edge):
         if isinstance(edge, LeafEdge):
-            for new_edge in self._fundamental_rule.apply(chart, grammar, edge):
-                yield new_edge
+            yield from self._fundamental_rule.apply(chart, grammar, edge)
 
 
 class PredictorRule(CachedTopDownPredictRule):
@@ -218,8 +215,7 @@ class FilteredCompleteFundamentalRule(FilteredSingleEdgeFundamentalRule):
         # Since the Filtered rule only works for grammars without empty productions,
         # we only have to bother with complete edges here.
         if edge.is_complete():
-            for new_edge in self._apply_complete(chart, grammar, edge):
-                yield new_edge
+            yield from self._apply_complete(chart, grammar, edge)
 
 
 # ////////////////////////////////////////////////////////////
@@ -236,8 +232,7 @@ class FeatureCompleteFundamentalRule(FeatureSingleEdgeFundamentalRule):
         for right_edge in chart.select(
             start=end, end=end, is_complete=True, lhs=left_edge.nextsym()
         ):
-            for new_edge in fr.apply(chart, grammar, left_edge, right_edge):
-                yield new_edge
+            yield from fr.apply(chart, grammar, left_edge, right_edge)
 
 
 class FeatureCompleterRule(CompleterRule):
@@ -516,7 +511,9 @@ def demo(
     """
     A demonstration of the Earley parsers.
     """
-    import sys, time
+    import sys
+    import time
+
     from nltk.parse.chart import demo_grammar
 
     # The grammar for ChartParser and SteppingChartParser:
