@@ -3,21 +3,20 @@
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Sam Huston <sjh900@gmail.com>
 #
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
 Implementation of 'TnT - A Statisical Part of Speech Tagger'
 by Thorsten Brants
 
-http://acl.ldc.upenn.edu/A/A00/A00-1031.pdf
+https://aclanthology.org/A00-1031.pdf
 """
 
 from math import log
-
 from operator import itemgetter
 
-from nltk.probability import FreqDist, ConditionalFreqDist
+from nltk.probability import ConditionalFreqDist, FreqDist
 from nltk.tag.api import TaggerI
 
 
@@ -89,13 +88,13 @@ class TnT(TaggerI):
         before being used to tag input.
 
         :param unk: instance of a POS tagger, conforms to TaggerI
-        :type  unk:(TaggerI)
+        :type  unk: TaggerI
         :param Trained: Indication that the POS tagger is trained or not
-        :type  Trained: boolean
+        :type  Trained: bool
         :param N: Beam search degree (see above)
-        :type  N:(int)
+        :type  N: int
         :param C: Capitalization flag
-        :type  C: boolean
+        :type  C: bool
 
         Initializer, creates frequency distributions to be used
         for tagging
@@ -330,7 +329,7 @@ class TnT(TaggerI):
         of a particular tag
         """
 
-        # if this word marks the end of the sentance,
+        # if this word marks the end of the sentence,
         # return the most probable tag
         if sent == []:
             (h, logp) = current_states[0]
@@ -342,7 +341,7 @@ class TnT(TaggerI):
         new_states = []
 
         # if the Capitalisation is requested,
-        # initalise the flag for this word
+        # initialise the flag for this word
         C = False
         if self._C and word[0].isupper():
             C = True
@@ -493,7 +492,7 @@ def demo2():
     s.train(d[(11) * 100 :])
 
     for i in range(10):
-        tacc = t.evaluate(d[i * 100 : ((i + 1) * 100)])
+        tacc = t.accuracy(d[i * 100 : ((i + 1) * 100)])
         tp_un = t.unknown / (t.known + t.unknown)
         tp_kn = t.known / (t.known + t.unknown)
         t.unknown = 0
@@ -505,7 +504,7 @@ def demo2():
         print("Percentage unknown:", tp_un)
         print("Accuracy over known words:", (tacc / tp_kn))
 
-        sacc = s.evaluate(d[i * 100 : ((i + 1) * 100)])
+        sacc = s.accuracy(d[i * 100 : ((i + 1) * 100)])
         sp_un = s.unknown / (s.known + s.unknown)
         sp_kn = s.known / (s.known + s.unknown)
         s.unknown = 0
@@ -519,7 +518,7 @@ def demo2():
 
 
 def demo3():
-    from nltk.corpus import treebank, brown
+    from nltk.corpus import brown, treebank
 
     d = list(treebank.tagged_sents())
     e = list(brown.tagged_sents())
@@ -551,14 +550,14 @@ def demo3():
         t.train(dtrain)
         s.train(etrain)
 
-        tacc = t.evaluate(dtest)
+        tacc = t.accuracy(dtest)
         tp_un = t.unknown / (t.known + t.unknown)
         tp_kn = t.known / (t.known + t.unknown)
         tknown += tp_kn
         t.unknown = 0
         t.known = 0
 
-        sacc = s.evaluate(etest)
+        sacc = s.accuracy(etest)
         sp_un = s.unknown / (s.known + s.unknown)
         sp_kn = s.known / (s.known + s.unknown)
         sknown += sp_kn
