@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Transformation-based learning
 #
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Marcus Uneson <marcus.uneson@gmail.com>
 #   based on previous (nltk2) version by
 #   Christopher Maloof, Edward Loper, Steven Bird
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see  LICENSE.TXT
 
 """
@@ -13,6 +12,8 @@ Transformation Based Learning
 
 A general purpose package for Transformation Based Learning,
 currently used by nltk.tag.BrillTagger.
+
+isort:skip_file
 """
 
 from nltk.tbl.template import Template
