@@ -6,7 +6,7 @@
 #         Ewan Klein <ewan@inf.ed.ac.uk> (modifications)
 #         Pierpaolo Pantone <> (modifications)
 #         Tom Aarsen <> (modifications)
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 #
 
@@ -28,16 +28,16 @@ domains and tasks. The basic logic is this:
 
 4. When instantiating Tokenizer objects, there are several options:
     * preserve_case. By default, it is set to True. If it is set to
-        False, then the tokenizer will downcase everything except for
-        emoticons.
+      False, then the tokenizer will downcase everything except for
+      emoticons.
     * reduce_len. By default, it is set to False. It specifies whether
-        to replace repeated character sequences of length 3 or greater
-        with sequences of length 3.
+      to replace repeated character sequences of length 3 or greater
+      with sequences of length 3.
     * strip_handles. By default, it is set to False. It specifies
-        whether to remove Twitter handles of text used in the
-        `tokenize` method.
+      whether to remove Twitter handles of text used in the
+      `tokenize` method.
     * match_phone_numbers. By default, it is set to True. It indicates
-        whether the `tokenize` method should look for phone numbers.
+      whether the `tokenize` method should look for phone numbers.
 """
 
 
@@ -48,6 +48,8 @@ from typing import List
 
 import regex  # https://github.com/nltk/nltk/issues/2409
 
+from nltk.tokenize.api import TokenizerI
+
 ######################################################################
 # The following strings are components in the regular expression
 # that is used for tokenizing. It's important that phone_number
@@ -60,7 +62,7 @@ import regex  # https://github.com/nltk/nltk/issues/2409
 # Most importantly, the final element should always be last, since it
 # does a last ditch whitespace-based tokenization of whatever is left.
 
-# ToDo: Update with http://en.wikipedia.org/wiki/List_of_emoticons ?
+# ToDo: Update with https://en.wikipedia.org/wiki/List_of_emoticons ?
 
 # This particular element is used in a couple ways, so we define it
 # with a name:
@@ -157,6 +159,12 @@ REGEXPS = (
     r"""(?:\#+[\w_]+[\w\'_\-]*[\w_]+)""",
     # email addresses
     r"""[\w.+-]+@[\w-]+\.(?:[\w-]\.?)+[\w-]""",
+    # Zero-Width-Joiner and Skin tone modifier emojis
+    """.(?:
+        [\U0001F3FB-\U0001F3FF]?(?:\u200d.[\U0001F3FB-\U0001F3FF]?)+
+        |
+        [\U0001F3FB-\U0001F3FF]
+    )""",
     # Remaining word types:
     r"""
     (?:[^\W\d_](?:[^\W\d_]|['\-_])+[^\W\d_]) # Words with apostrophes or dashes.
@@ -194,6 +202,7 @@ HANDLES_RE = regex.compile(
     r"(([A-Za-z0-9_]){15}(?!@)|([A-Za-z0-9_]){1,14}(?![A-Za-z0-9_]*@))"
 )
 
+
 ######################################################################
 # Functions for converting html entities
 ######################################################################
@@ -269,7 +278,7 @@ def _replace_html_entities(text, keep=(), remove_illegal=True, encoding="utf-8")
 ######################################################################
 
 
-class TweetTokenizer:
+class TweetTokenizer(TokenizerI):
     r"""
     Tokenizer for tweets.
 
@@ -354,7 +363,7 @@ class TweetTokenizer:
         return words
 
     @property
-    def WORD_RE(self) -> regex.Pattern:
+    def WORD_RE(self) -> "regex.Pattern":
         """Core TweetTokenizer regex"""
         # Compiles the regex for this and all future instantiations of TweetTokenizer.
         if not type(self)._WORD_RE:
@@ -365,7 +374,7 @@ class TweetTokenizer:
         return type(self)._WORD_RE
 
     @property
-    def PHONE_WORD_RE(self) -> regex.Pattern:
+    def PHONE_WORD_RE(self) -> "regex.Pattern":
         """Secondary core TweetTokenizer regex"""
         # Compiles the regex for this and all future instantiations of TweetTokenizer.
         if not type(self)._PHONE_WORD_RE:
