@@ -3,8 +3,9 @@
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Michael Heilman <mheilman@cmu.edu> (re-port from http://www.cis.upenn.edu/~treebank/tokenizer.sed)
+#         Tom Aarsen <> (modifications)
 #
-# URL: <http://nltk.sourceforge.net>
+# URL: <https://www.nltk.org>
 # For license information, see LICENSE.TXT
 
 r"""
@@ -17,6 +18,8 @@ and available at http://www.cis.upenn.edu/~treebank/tokenizer.sed.
 """
 
 import re
+import warnings
+from typing import Iterator, List, Tuple
 
 from nltk.tokenize.api import TokenizerI
 from nltk.tokenize.destructive import MacIntyreContractions
@@ -26,8 +29,6 @@ from nltk.tokenize.util import align_tokens
 class TreebankWordTokenizer(TokenizerI):
     r"""
     The Treebank tokenizer uses regular expressions to tokenize text as in Penn Treebank.
-    This is the method that is invoked by ``word_tokenize()``.  It assumes that the
-    text has already been segmented into sentences, e.g. using ``sent_tokenize()``.
 
     This tokenizer performs the following steps:
 
@@ -36,16 +37,16 @@ class TreebankWordTokenizer(TokenizerI):
     - split off commas and single quotes, when followed by whitespace
     - separate periods that appear at the end of line
 
-        >>> from nltk.tokenize import TreebankWordTokenizer
-        >>> s = '''Good muffins cost $3.88\nin New York.  Please buy me\ntwo of them.\nThanks.'''
-        >>> TreebankWordTokenizer().tokenize(s)
-        ['Good', 'muffins', 'cost', '$', '3.88', 'in', 'New', 'York.', 'Please', 'buy', 'me', 'two', 'of', 'them.', 'Thanks', '.']
-        >>> s = "They'll save and invest more."
-        >>> TreebankWordTokenizer().tokenize(s)
-        ['They', "'ll", 'save', 'and', 'invest', 'more', '.']
-        >>> s = "hi, my name can't hello,"
-        >>> TreebankWordTokenizer().tokenize(s)
-        ['hi', ',', 'my', 'name', 'ca', "n't", 'hello', ',']
+    >>> from nltk.tokenize import TreebankWordTokenizer
+    >>> s = '''Good muffins cost $3.88\nin New York.  Please buy me\ntwo of them.\nThanks.'''
+    >>> TreebankWordTokenizer().tokenize(s)
+    ['Good', 'muffins', 'cost', '$', '3.88', 'in', 'New', 'York.', 'Please', 'buy', 'me', 'two', 'of', 'them.', 'Thanks', '.']
+    >>> s = "They'll save and invest more."
+    >>> TreebankWordTokenizer().tokenize(s)
+    ['They', "'ll", 'save', 'and', 'invest', 'more', '.']
+    >>> s = "hi, my name can't hello,"
+    >>> TreebankWordTokenizer().tokenize(s)
+    ['hi', ',', 'my', 'name', 'ca', "n't", 'hello', ',']
     """
 
     # starting quotes
@@ -86,8 +87,8 @@ class TreebankWordTokenizer(TokenizerI):
 
     # ending quotes
     ENDING_QUOTES = [
+        (re.compile(r"''"), " '' "),
         (re.compile(r'"'), " '' "),
-        (re.compile(r"(\S)(\'\')"), r"\1 \2 "),
         (re.compile(r"([^' ])('[sS]|'[mM]|'[dD]|') "), r"\1 \2 "),
         (re.compile(r"([^' ])('ll|'LL|'re|'RE|'ve|'VE|n't|N'T) "), r"\1 \2 "),
     ]
@@ -97,7 +98,43 @@ class TreebankWordTokenizer(TokenizerI):
     CONTRACTIONS2 = list(map(re.compile, _contractions.CONTRACTIONS2))
     CONTRACTIONS3 = list(map(re.compile, _contractions.CONTRACTIONS3))
 
-    def tokenize(self, text, convert_parentheses=False, return_str=False):
+    def tokenize(
+        self, text: str, convert_parentheses: bool = False, return_str: bool = False
+    ) -> List[str]:
+        r"""Return a tokenized copy of `text`.
+
+        >>> from nltk.tokenize import TreebankWordTokenizer
+        >>> s = '''Good muffins cost $3.88 (roughly 3,36 euros)\nin New York.  Please buy me\ntwo of them.\nThanks.'''
+        >>> TreebankWordTokenizer().tokenize(s)
+        ['Good', 'muffins', 'cost', '$', '3.88', '(', 'roughly', '3,36',
+        'euros', ')', 'in', 'New', 'York.', 'Please', 'buy', 'me', 'two',
+        'of', 'them.', 'Thanks', '.']
+        >>> TreebankWordTokenizer().tokenize(s, convert_parentheses=True)
+        ['Good', 'muffins', 'cost', '$', '3.88', '-LRB-', 'roughly', '3,36',
+        'euros', '-RRB-', 'in', 'New', 'York.', 'Please', 'buy', 'me', 'two',
+        'of', 'them.', 'Thanks', '.']
+        >>> TreebankWordTokenizer().tokenize(s, return_str=True)
+        ' Good muffins cost  $ 3.88  ( roughly 3,36 euros ) \nin New York.  Please buy me\ntwo of them.\nThanks .  '
+
+        :param text: A string with a sentence or sentences.
+        :type text: str
+        :param convert_parentheses: if True, replace parentheses to PTB symbols,
+            e.g. `(` to `-LRB-`. Defaults to False.
+        :type convert_parentheses: bool, optional
+        :param return_str: If True, return tokens as space-separated string,
+            defaults to False.
+        :type return_str: bool, optional
+        :return: List of tokens from `text`.
+        :rtype: List[str]
+        """
+        if return_str is not False:
+            warnings.warn(
+                "Parameter 'return_str' has been deprecated and should no "
+                "longer be used.",
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+
         for regexp, substitution in self.STARTING_QUOTES:
             text = regexp.sub(substitution, text)
 
@@ -132,10 +169,11 @@ class TreebankWordTokenizer(TokenizerI):
         # for regexp in self._contractions.CONTRACTIONS4:
         #     text = regexp.sub(r' \1 \2 \3 ', text)
 
-        return text if return_str else text.split()
+        return text.split()
 
-    def span_tokenize(self, text):
+    def span_tokenize(self, text: str) -> Iterator[Tuple[int, int]]:
         r"""
+        Returns the spans of the tokens in ``text``.
         Uses the post-hoc nltk.tokens.align_tokens to return the offset spans.
 
             >>> from nltk.tokenize import TreebankWordTokenizer
@@ -152,22 +190,9 @@ class TreebankWordTokenizer(TokenizerI):
             >>> [s[start:end] for start, end in TreebankWordTokenizer().span_tokenize(s)] == expected
             True
 
-            Additional example
-            >>> from nltk.tokenize import TreebankWordTokenizer
-            >>> s = '''I said, "I'd like to buy some ''good muffins" which cost $3.88\n each in New (York)."'''
-            >>> expected = [(0, 1), (2, 6), (6, 7), (8, 9), (9, 10), (10, 12),
-            ... (13, 17), (18, 20), (21, 24), (25, 29), (30, 32), (32, 36),
-            ... (37, 44), (44, 45), (46, 51), (52, 56), (57, 58), (58, 62),
-            ... (64, 68), (69, 71), (72, 75), (76, 77), (77, 81), (81, 82),
-            ... (82, 83), (83, 84)]
-            >>> list(TreebankWordTokenizer().span_tokenize(s)) == expected
-            True
-            >>> expected = ['I', 'said', ',', '"', 'I', "'d", 'like', 'to',
-            ... 'buy', 'some', "''", "good", 'muffins', '"', 'which', 'cost',
-            ... '$', '3.88', 'each', 'in', 'New', '(', 'York', ')', '.', '"']
-            >>> [s[start:end] for start, end in TreebankWordTokenizer().span_tokenize(s)] == expected
-            True
-
+        :param text: A string with a sentence or sentences.
+        :type text: str
+        :yield: Tuple[int, int]
         """
         raw_tokens = self.tokenize(text)
 
@@ -196,24 +221,25 @@ class TreebankWordDetokenizer(TokenizerI):
     the Treebank tokenizer's regexes.
 
     Note:
-    - There're additional assumption mades when undoing the padding of [;@#$%&]
+
+    - There're additional assumption mades when undoing the padding of ``[;@#$%&]``
       punctuation symbols that isn't presupposed in the TreebankTokenizer.
     - There're additional regexes added in reversing the parentheses tokenization,
-       - the r'([\]\)\}\>])\s([:;,.])' removes the additional right padding added
-         to the closing parentheses precedding [:;,.].
+       such as the ``r'([\]\)\}\>])\s([:;,.])'``, which removes the additional right
+       padding added to the closing parentheses precedding ``[:;,.]``.
     - It's not possible to return the original whitespaces as they were because
-      there wasn't explicit records of where '\n', '\t' or '\s' were removed at
+      there wasn't explicit records of where `'\n'`, `'\t'` or `'\s'` were removed at
       the text.split() operation.
 
-        >>> from nltk.tokenize.treebank import TreebankWordTokenizer, TreebankWordDetokenizer
-        >>> s = '''Good muffins cost $3.88\nin New York.  Please buy me\ntwo of them.\nThanks.'''
-        >>> d = TreebankWordDetokenizer()
-        >>> t = TreebankWordTokenizer()
-        >>> toks = t.tokenize(s)
-        >>> d.detokenize(toks)
-        'Good muffins cost $3.88 in New York. Please buy me two of them. Thanks.'
+    >>> from nltk.tokenize.treebank import TreebankWordTokenizer, TreebankWordDetokenizer
+    >>> s = '''Good muffins cost $3.88\nin New York.  Please buy me\ntwo of them.\nThanks.'''
+    >>> d = TreebankWordDetokenizer()
+    >>> t = TreebankWordTokenizer()
+    >>> toks = t.tokenize(s)
+    >>> d.detokenize(toks)
+    'Good muffins cost $3.88 in New York. Please buy me two of them. Thanks.'
 
-    The MXPOST parentheses substitution can be undone using the `convert_parentheses`
+    The MXPOST parentheses substitution can be undone using the ``convert_parentheses``
     parameter:
 
     >>> s = '''Good muffins cost $3.88\nin New (York).  Please (buy) me\ntwo of them.\n(Thanks).'''
@@ -229,14 +255,14 @@ class TreebankWordDetokenizer(TokenizerI):
     During tokenization it's safe to add more spaces but during detokenization,
     simply undoing the padding doesn't really help.
 
-    - During tokenization, left and right pad is added to [!?], when
-      detokenizing, only left shift the [!?] is needed.
-      Thus (re.compile(r'\s([?!])'), r'\g<1>')
+    - During tokenization, left and right pad is added to ``[!?]``, when
+      detokenizing, only left shift the ``[!?]`` is needed.
+      Thus ``(re.compile(r'\s([?!])'), r'\g<1>')``.
 
-    - During tokenization [:,] are left and right padded but when detokenizing,
+    - During tokenization ``[:,]`` are left and right padded but when detokenizing,
       only left shift is necessary and we keep right pad after comma/colon
       if the string after is a non-digit.
-      Thus (re.compile(r'\s([:,])\s([^\d])'), r'\1 \2')
+      Thus ``(re.compile(r'\s([:,])\s([^\d])'), r'\1 \2')``.
 
     >>> from nltk.tokenize.treebank import TreebankWordDetokenizer
     >>> toks = ['hello', ',', 'i', 'ca', "n't", 'feel', 'my', 'feet', '!', 'Help', '!', '!']
@@ -320,13 +346,16 @@ class TreebankWordDetokenizer(TokenizerI):
         (re.compile(r"``"), r'"'),
     ]
 
-    def tokenize(self, tokens, convert_parentheses=False):
+    def tokenize(self, tokens: List[str], convert_parentheses: bool = False) -> str:
         """
         Treebank detokenizer, created by undoing the regexes from
         the TreebankWordTokenizer.tokenize.
 
         :param tokens: A list of strings, i.e. tokenized text.
-        :type tokens: list(str)
+        :type tokens: List[str]
+        :param convert_parentheses: if True, replace PTB symbols with parentheses,
+            e.g. `-LRB-` to `(`. Defaults to False.
+        :type convert_parentheses: bool, optional
         :return: str
         """
         text = " ".join(tokens)
@@ -366,6 +395,6 @@ class TreebankWordDetokenizer(TokenizerI):
 
         return text.strip()
 
-    def detokenize(self, tokens, convert_parentheses=False):
+    def detokenize(self, tokens: List[str], convert_parentheses: bool = False) -> str:
         """Duck-typing the abstract *tokenize()*."""
         return self.tokenize(tokens, convert_parentheses)
