@@ -1,14 +1,15 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Machine Translation
 #
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>, Tah Wei Hoon <hoon.tw@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
 Experimental features for machine translation.
 These interfaces are prone to change.
+
+isort:skip_file
 """
 
 from nltk.translate.api import AlignedSent, Alignment, PhraseTable
