@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 # Natural Language Toolkit: Stack decoder
 #
 # Copyright (C) 2001-2021 NLTK Project
 # Author: Tah Wei Hoon <hoon.tw@gmail.com>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -47,7 +46,7 @@ from collections import defaultdict
 from math import log
 
 
-class StackDecoder(object):
+class StackDecoder:
     """
     Phrase-based stack decoder for machine translation
 
@@ -234,8 +233,8 @@ class StackDecoder(object):
         :type src_sentence: tuple(str)
 
         :return: Scores of subsequences referenced by their start and
-        end positions. For example, result[2][5] is the score of the
-        subsequence covering positions 2, 3, and 4.
+            end positions. For example, result[2][5] is the score of the
+            subsequence covering positions 2, 3, and 4.
         :rtype: dict(int: (dict(int): float))
         """
         scores = defaultdict(lambda: defaultdict(lambda: float("-inf")))
@@ -336,7 +335,7 @@ class StackDecoder(object):
         return valid_phrases
 
 
-class _Hypothesis(object):
+class _Hypothesis:
     """
     Partial solution to a translation.
 
@@ -450,7 +449,7 @@ class _Hypothesis(object):
         output.extend(hypothesis.trg_phrase)
 
 
-class _Stack(object):
+class _Stack:
     """
     Collection of _Hypothesis objects
     """
